# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.course_public import CoursePublic  # noqa: E501

class TestCoursePublic(unittest.TestCase):
    """CoursePublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CoursePublic:
        """Test CoursePublic
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CoursePublic`
        """
        model = CoursePublic()  # noqa: E501
        if include_optional:
            return CoursePublic(
                description = '',
                id = 56,
                modules = [
                    chat_server_connector.models.course_module_public.CourseModulePublic(
                        id = 56, 
                        lessons = [
                            chat_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                id = 56, 
                                title = '', )
                            ], 
                        public_description = '', 
                        short_description = '', 
                        title = '', )
                    ],
                payment_type = 'paid',
                title = '',
                url = ''
            )
        else:
            return CoursePublic(
                id = 56,
                title = '',
        )
        """

    def testCoursePublic(self):
        """Test CoursePublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_list_chat_session_get_with_chat_data import ResponseWrapperListChatSessionGetWithChatData  # noqa: E501

class TestResponseWrapperListChatSessionGetWithChatData(unittest.TestCase):
    """ResponseWrapperListChatSessionGetWithChatData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListChatSessionGetWithChatData:
        """Test ResponseWrapperListChatSessionGetWithChatData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListChatSessionGetWithChatData`
        """
        model = ResponseWrapperListChatSessionGetWithChatData()  # noqa: E501
        if include_optional:
            return ResponseWrapperListChatSessionGetWithChatData(
                done = True,
                result = [
                    chat_server_connector.models.chat_session_get_with_chat_data.ChatSessionGetWithChatData(
                        id = 56, 
                        chat_id = 56, 
                        creator_id = 56, 
                        credentials = chat_server_connector.models.credentials.Credentials(), 
                        chat_session_type = 'TEXT', 
                        created_at = 56, 
                        ended_at = 56, 
                        last_activity_at = 56, 
                        messages = [
                            chat_server_connector.models.chat_message_read.ChatMessageRead(
                                text = '', 
                                file_id = '', 
                                id = 56, 
                                chat_message_type = 'TEXT', 
                                run_id = '', 
                                chat_id = 56, 
                                chat_member_id = 56, 
                                added_at = 56, 
                                attachments = [
                                    chat_server_connector.models.chat_message_attachment_read.ChatMessageAttachmentRead(
                                        file_id = '', 
                                        attachment_type = 'IMAGE', 
                                        id = 56, )
                                    ], 
                                chat_session = chat_server_connector.models.chat_session_get.ChatSessionGet(
                                    id = 56, 
                                    chat_id = 56, 
                                    creator_id = 56, 
                                    credentials = chat_server_connector.models.credentials.Credentials(), 
                                    chat_session_type = 'TEXT', 
                                    created_at = 56, 
                                    ended_at = 56, 
                                    last_activity_at = 56, ), 
                                usage = chat_server_connector.models.session_usage.SessionUsage(
                                    total_mentorcoin = 1.337, 
                                    by_type = [
                                        chat_server_connector.models.usage_by_type.UsageByType(
                                            type = 'text', 
                                            mentorcoin = 1.337, )
                                        ], ), )
                            ], 
                        chat = chat_server_connector.models.chat_get_with_members.ChatGetWithMembers(
                            id = 56, 
                            uuid = '', 
                            chat_type = 'SOLO', 
                            avatar_id = '', 
                            name = '', 
                            description = '', 
                            messaging_enabled = True, 
                            permalink_enabled = True, 
                            is_visible = True, 
                            topic_slug = '', 
                            is_muted = True, 
                            created_at = 56, 
                            last_updated_at = 56, 
                            members = [
                                chat_server_connector.models.chat_member_get.ChatMemberGet(
                                    role = null, 
                                    user_id = 56, 
                                    bot_id = 56, 
                                    id = 56, 
                                    chat_id = 56, 
                                    added_at = 56, 
                                    last_seen_at = 56, 
                                    is_removed = True, 
                                    is_banned = True, 
                                    is_muted = True, 
                                    user = chat_server_connector.models.contact.Contact(
                                        id = 56, 
                                        role = 1, 
                                        nickname = '', 
                                        personal_description = '', 
                                        first_name = '', 
                                        last_name = '', 
                                        avatar_id = '', 
                                        is_online = True, 
                                        address = null, 
                                        phone_number = '', 
                                        is_public_email = True, 
                                        is_public_phone_number = True, 
                                        is_public_city = True, 
                                        is_public_country = True, 
                                        email = '', ), 
                                    bot = chat_server_connector.models.ai_assistant_get.AiAssistantGet(
                                        allow_text = True, 
                                        allow_voice = True, 
                                        approved_urls = [
                                            ''
                                            ], 
                                        avatar_id = '', 
                                        banned_keywords = [
                                            ''
                                            ], 
                                        conversation_starter = '', 
                                        conversation_style = 'formal', 
                                        created_at = 56, 
                                        deleted_at = 56, 
                                        function = 'support', 
                                        goals = [
                                            chat_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                                                additional_prompt = '', 
                                                ai_assistant_id = 56, 
                                                course_ids = [
                                                    56
                                                    ], 
                                                created_at = 56, 
                                                engagement = 56, 
                                                engagement_opt_out_duration = 56, 
                                                engagement_preset = chat_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                                    created_at = 56, 
                                                    engagement = 56, 
                                                    engagement_opt_out_duration = 56, 
                                                    id = 56, 
                                                    max_engagement_count = 56, 
                                                    max_engagement_period = 56, 
                                                    max_total_engagement_count = 56, 
                                                    name = '', 
                                                    order = 56, ), 
                                                engagement_preset_id = 56, 
                                                id = 56, 
                                                interactions_summary = chat_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                                    is_available = True, 
                                                    last_engagement_at = 56, 
                                                    last_opt_out_at = 56, 
                                                    recent_interaction_count = 56, 
                                                    total_interaction_count = 56, ), 
                                                is_active = True, 
                                                is_fullfilled = True, 
                                                last_updated_at = 56, 
                                                max_engagement_count = 56, 
                                                max_engagement_period = 56, 
                                                max_total_engagement_count = 56, 
                                                name = '', 
                                                page_url = '', 
                                                primary_course = chat_server_connector.models.course_public.CoursePublic(
                                                    description = '', 
                                                    id = 56, 
                                                    modules = [
                                                        chat_server_connector.models.course_module_public.CourseModulePublic(
                                                            id = 56, 
                                                            lessons = [
                                                                chat_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                                    id = 56, 
                                                                    title = '', )
                                                                ], 
                                                            public_description = '', 
                                                            short_description = '', 
                                                            title = '', )
                                                        ], 
                                                    payment_type = 'paid', 
                                                    title = '', 
                                                    url = '', ), 
                                                primary_course_id = 56, )
                                            ], 
                                        id = 56, 
                                        is_active = True, 
                                        is_available = True, 
                                        is_live = True, 
                                        knowledgebase_state = chat_server_connector.models.knowledgebase_state.KnowledgebaseState(
                                            course_data = chat_server_connector.models.collection_state.CollectionState(
                                                error_message = '', 
                                                status = 'unavailable', ), ), 
                                        last_updated_at = 56, 
                                        lexicon_items = [
                                            chat_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                                                ai_assistant_id = 56, 
                                                deleted_at = 56, 
                                                id = 56, 
                                                order = 56, 
                                                pronounciation = '', 
                                                term = '', )
                                            ], 
                                        name = '', 
                                        prefer_voice = True, 
                                        system_prompt = '', 
                                        system_prompt_support = '', 
                                        system_prompt_tutor = '', 
                                        voice_id = 56, ), )
                                ], ), 
                        tokens_used = 1.337, )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListChatSessionGetWithChatData(
                done = True,
        )
        """

    def testResponseWrapperListChatSessionGetWithChatData(self):
        """Test ResponseWrapperListChatSessionGetWithChatData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
